@@ -14,16 +14,8 @@
 # Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
 
 
+import configparser
 
-import sys
-
-if sys.version_info >= ( 3, ):
-    import configparser
-else:
-    #python 2.x
-    import configparser as configparser
-
-import re
 
 # inspired from http://code.google.com/p/iniparse/ - although their implementation is
 # quite different
@@ -34,6 +26,7 @@ class ConfigLineOrder:
     It keeps track of all lines (including comments) in the _lines list. This list
     either contains SectionLine() instances or CommentLine() instances.
     """
+
     def __init__(self):
         self._lines = []
 
@@ -64,7 +57,7 @@ class ConfigLineOrder:
             self._append(CommentLine(line))
 
     def keys(self):
-        return [ i.name for i in self._lines if i.type == 'section' ]
+        return [i.name for i in self._lines if i.type == 'section']
 
     def __setitem__(self, key, value):
         section = SectionLine(key)
@@ -83,28 +76,30 @@ class ConfigLineOrder:
         self._lines.remove(line)
 
     def __iter__(self):
-        #return self._lines.__iter__()
+        # return self._lines.__iter__()
         for line in self._lines:
             if line.type == 'section':
                 yield line.name
-        raise StopIteration()
+
 
 class Line:
     """Base class for all line objects"""
+
     def __init__(self, name, type):
         self.name = name
         self.type = type
 
+
 class SectionLine(Line):
     """
     This class represents a [section]. It stores all lines which belongs to
     this certain section in the _lines list. The _lines list either contains
     CommentLine() or OptionLine() instances.
     """
-    def __init__(self, sectname, dict = {}):
-        Line.__init__(self, sectname, 'section')
+
+    def __init__(self, sectname):
+        super().__init__(sectname, 'section')
         self._lines = []
-        self._dict = dict
 
     def _find(self, name):
         for line in self._lines:
@@ -112,14 +107,14 @@ class SectionLine(Line):
                 return line
         return None
 
-    def _add_option(self, optname, value = None, line = None, sep = '='):
+    def _add_option(self, optname, value=None, line=None, sep='='):
         if value is None and line is None:
             raise configparser.Error('Either value or line must be passed in')
         elif value and line:
             raise configparser.Error('value and line are mutually exclusive')
 
         if value is not None:
-            line = '%s%s%s' % (optname, sep, value)
+            line = f'{optname}{sep}{value}'
         opt = self._find(optname)
         if opt:
             opt.format(line)
@@ -130,13 +125,13 @@ class SectionLine(Line):
         self._lines.append(CommentLine(line))
 
     def copy(self):
-        return dict(list(self.items()))
+        return dict(self.items())
 
     def items(self):
-        return [ (i.name, i.value) for i in self._lines if i.type == 'option' ]
+        return [(i.name, i.value) for i in self._lines if i.type == 'option']
 
     def keys(self):
-        return [ i.name for i in self._lines ]
+        return [i.name for i in self._lines]
 
     def __setitem__(self, key, val):
         self._add_option(key, val)
@@ -160,24 +155,27 @@ class SectionLine(Line):
     def __iter__(self):
         for line in self._lines:
             yield line.name
-        raise StopIteration()
 
 
 class CommentLine(Line):
     """Store a commentline"""
+
     def __init__(self, line):
-        Line.__init__(self, line.strip('\n'), 'comment')
+        super().__init__(line.strip('\n'), 'comment')
 
     def __str__(self):
         return self.name
 
+
 class OptionLine(Line):
     """
-    This class represents an option. The class' "name" attribute is used
+    This class represents an option. The class' ``name`` attribute is used
     to store the option's name and the "value" attribute contains the option's
-    value. The "frmt" attribute preserves the format which was used in the configuration
+    value. The ``frmt`` attribute preserves the format which was used in the configuration
     file.
-    Example:
+
+    Example::
+
         optionx:<SPACE><SPACE>value
         => self.frmt = '%s:<SPACE><SPACE>%s'
         optiony<SPACE>=<SPACE>value<SPACE>;<SPACE>some_comment
@@ -185,7 +183,7 @@ class OptionLine(Line):
     """
 
     def __init__(self, optname, line):
-        Line.__init__(self, optname, 'option')
+        super().__init__(optname, 'option')
         self.name = optname
         self.format(line)
 
@@ -211,8 +209,9 @@ class OscConfigParser(configparser.ConfigParser):
     In order to keep the order and the format it makes use of the ConfigLineOrder()
     class.
     """
-    def __init__(self, defaults={}):
-        configparser.ConfigParser.__init__(self, defaults)
+
+    def __init__(self, defaults=None):
+        super().__init__(defaults or {}, interpolation=None)
         self._sections = ConfigLineOrder()
 
     # XXX: unfortunately we have to override the _read() method from the ConfigParser()
@@ -254,17 +253,19 @@ class OscConfigParser(configparser.ConfigParser):
                     #cursect[optname] = "%s\n%s" % (cursect[optname], value)
                     #self.set(cursect, optname, "%s\n%s" % (self.get(cursect, optname), value))
                     if cursect == configparser.DEFAULTSECT:
-                        self._defaults[optname] = "%s\n%s" % (self._defaults[optname], value)
+                        self._defaults[optname] = f"{self._defaults[optname]}\n{value}"
                     else:
                         # use the raw value here (original version uses raw=False)
-                        self._sections[cursect]._find(optname).value = '%s\n%s' % (self.get(cursect, optname, raw=True), value)
+                        self._sections[cursect]._find(optname).value = f'{self.get(cursect, optname, raw=True)}\n{value}'
             # a section header or option header?
             else:
                 # is it a section header?
                 mo = self.SECTCRE.match(line)
                 if mo:
                     sectname = mo.group('header')
-                    if sectname in self._sections:
+                    if self._strict and sectname in self._sections:
+                        raise configparser.DuplicateSectionError(sectname, fpname, lineno)
+                    elif sectname in self._sections:
                         cursect = self._sections[sectname]
                     elif sectname == configparser.DEFAULTSECT:
                         cursect = self._defaults
@@ -288,14 +289,16 @@ class OscConfigParser(configparser.ConfigParser):
                             # ';' is a comment delimiter only if it follows
                             # a spacing character
                             pos = optval.find(';')
-                            if pos != -1 and optval[pos-1].isspace():
+                            if pos != -1 and optval[pos - 1].isspace():
                                 optval = optval[:pos]
                         optval = optval.strip()
                         # allow empty values
                         if optval == '""':
                             optval = ''
                         optname = self.optionxform(optname.rstrip())
-                        if cursect == configparser.DEFAULTSECT:
+                        if self._strict and optname in self._sections[cursect]:
+                            raise configparser.DuplicateOptionError(sectname, optname, fpname, lineno)
+                        elif cursect == configparser.DEFAULTSECT:
                             self._defaults[optname] = optval
                         else:
                             self._sections[cursect]._add_option(optname, line=line)
@@ -309,9 +312,9 @@ class OscConfigParser(configparser.ConfigParser):
                         e.append(lineno, repr(line))
         # if any parsing errors occurred, raise an exception
         if e:
-            raise e # pylint: disable-msg=E0702
+            raise e  # pylint: disable-msg=E0702
 
-    def write(self, fp, comments = False):
+    def write(self, fp, comments=False):
         """
         write the configuration file. If comments is True all comments etc.
         will be written to fp otherwise the ConfigParsers' default write method
@@ -321,7 +324,7 @@ class OscConfigParser(configparser.ConfigParser):
             fp.write(str(self))
             fp.write('\n')
         else:
-            configparser.ConfigParser.write(self, fp)
+            super().write(fp)
 
     def has_option(self, section, option, proper=False, **kwargs):
         """
@@ -330,8 +333,8 @@ class OscConfigParser(configparser.ConfigParser):
         this section and not "inherited" from the default.
         """
         if proper:
-            return self.optionxform(option) in list(self._sections[section].keys())
-        return configparser.ConfigParser.has_option(self, section, option, **kwargs)
+            return self.optionxform(option) in self._sections[section].keys()
+        return super().has_option(section, option, **kwargs)
 
     # XXX: simplify!
     def __str__(self):
@@ -343,7 +346,7 @@ class OscConfigParser(configparser.ConfigParser):
                     first = False
                 else:
                     ret.append('')
-                ret.append('[%s]' % line.name)
+                ret.append(f'[{line.name}]')
                 for sline in line._lines:
                     if sline.name == '__name__':
                         continue
@@ -357,4 +360,10 @@ class OscConfigParser(configparser.ConfigParser):
                 ret.append(str(line))
         return '\n'.join(ret)
 
+    def _validate_value_types(self, section="", option="", value=""):
+        if not isinstance(section, str):
+            raise TypeError("section names must be strings")
+        if not isinstance(option, str):
+            raise TypeError("option keys must be strings")
+
 # vim: sw=4 et
