@@ -11,8 +11,9 @@ import re
 import shutil
 import subprocess
 import sys
-
 from tempfile import NamedTemporaryFile, mkdtemp
+from typing import List
+from typing import Optional
 from urllib.parse import urlsplit
 from urllib.request import URLError, HTTPError
 from xml.etree import ElementTree as ET
@@ -21,7 +22,7 @@ from . import conf
 from . import connection
 from . import core
 from . import oscerr
-from .core import get_buildinfo, meta_exists, quote_plus, get_buildconfig, dgst
+from .core import get_buildinfo, meta_exists, get_buildconfig, dgst
 from .core import get_binarylist, get_binary_file, run_external, return_external, raw_input
 from .fetch import Fetcher, OscFileGrabber, verify_pacs
 from .meter import create_text_meter
@@ -275,7 +276,9 @@ class Pac:
         else:
             release = self.mp['release'].encode()
 
-        if self.mp['name'].startswith('container:'):
+        if self.mp['binary'] == 'updateinfo.xml':
+            canonname = 'updateinfo.xml'
+        elif self.mp['name'].startswith('container:'):
             canonname = self.mp['name'] + '.tar.xz'
         elif pacsuffix == 'deb':
             canonname = debquery.DebQuery.filename(self.mp['name'].encode(), epoch, self.mp['version'].encode(), release, self.mp['arch'].encode())
@@ -450,6 +453,11 @@ def get_built_files(pacdir, buildtype):
                                     '-type', 'f'],
                                    stdout=subprocess.PIPE).stdout.read().strip()
         s_built = ''
+    elif buildtype == 'productcompose':
+        b_built = subprocess.Popen(['find', os.path.join(pacdir, 'PRODUCT'),
+                                    '-type', 'f'],
+                                   stdout=subprocess.PIPE).stdout.read().strip()
+        s_built = ''
     else:
         print('WARNING: Unknown package type \'%s\'.' % buildtype, file=sys.stderr)
         b_built = ''
@@ -474,7 +482,6 @@ def get_repo(path):
     return None
 
 
-
 def get_prefer_pkgs(dirs, wanted_arch, type, cpio):
     paths = []
     repositories = []
@@ -607,7 +614,7 @@ def calculate_prj_pac(store, opts, descr):
 
 
 def calculate_build_root_user(vm_type):
-    if vm_type in ("kvm", "podman"):
+    if vm_type in ("kvm", "podman", "qemu"):
         return getpass.getuser()
     return None
 
@@ -627,10 +634,12 @@ def calculate_build_root(apihost, prj, pac, repo, arch, user=None):
     return buildroot
 
 
-def build_as_user():
-    if conf.config["su-wrapper"]:
-        return False
-    return True
+def build_as_user(vm_type=None):
+    if not conf.config.su_wrapper:
+        return True
+    if calculate_build_root_user(vm_type):
+        return True
+    return False
 
 
 def su_wrapper(cmd):
@@ -661,6 +670,83 @@ def run_build(opts, *args):
     return run_external(cmd[0], *cmd[1:])
 
 
+def create_build_descr_data(
+    build_descr_path: Optional[str],
+    *,
+    build_type: Optional[str],
+    repo: Optional[str] = None,
+    arch: Optional[str] = None,
+    prefer_pkgs: Optional[List[str]] = None,
+    define: Optional[List[str]] = None,
+    define_with: Optional[List[str]] = None,
+    define_without: Optional[List[str]] = None,
+):
+    if build_descr_path:
+        build_descr_path = os.path.abspath(build_descr_path)
+        topdir = os.path.dirname(build_descr_path)
+    else:
+        topdir = None
+    result_data = []
+
+    if build_descr_path:
+        print(f"Using local file: {os.path.basename(build_descr_path)}", file=sys.stderr)
+        with open(build_descr_path, "rb") as f:
+            build_descr_data = f.read()
+
+        # HACK: there's no api to provide custom defines
+        # TODO: check if we're working with a spec?
+        defines: List[bytes] = []
+        for i in define or []:
+            defines.append(f"%define {i}".encode("utf-8"))
+        for i in define_with or []:
+            defines.append(f"%define _with_{i} 1".encode("utf-8"))
+        for i in define_without or []:
+            defines.append(f"%define _without_{i} 1".encode("utf-8"))
+        if defines:
+            build_descr_data = b"\n".join(defines) + b"\n\n" + build_descr_data
+
+        # build recipe must go first for compatibility with the older OBS versions
+        result_data.append((os.path.basename(build_descr_path).encode("utf-8"), build_descr_data))
+
+    if topdir:
+        for include_file in glob.glob(os.path.join(topdir, "*.inc")):
+            fn = os.path.basename(include_file)
+            print(f"Using local file: {fn}", file=sys.stderr)
+            with open(include_file, "rb") as f:
+                result_data.append((fn.encode("utf-8"), f.read()))
+
+    if topdir:
+        buildenv_file = os.path.join(topdir, f"_buildenv.{repo}.{arch}")
+        if not os.path.isfile(buildenv_file):
+            buildenv_file = os.path.join(topdir, f"_buildenv")
+        if os.path.isfile(buildenv_file):
+            print(f"Using local file: {os.path.basename(buildenv_file)}", file=sys.stderr)
+            with open(buildenv_file, "rb") as f:
+                result_data.append((b"buildenv", f.read()))
+
+    if topdir:
+        service_file = os.path.join(topdir, "_service")
+        if os.path.isfile(service_file):
+            print("Using local file: _service", file=sys.stderr)
+            with open(service_file, "rb") as f:
+                result_data.append((b"_service", f.read()))
+
+    if not result_data and not prefer_pkgs:
+        return None, {}
+
+    cpio_data = cpio.CpioWrite()
+    for key, value in result_data:
+        cpio_data.add(key, value)
+
+    if prefer_pkgs:
+        print(f"Scanning the following dirs for local preferred packages: {', '.join(prefer_pkgs)}", file=sys.stderr)
+        prefer_pkgs_result = get_prefer_pkgs(prefer_pkgs, arch, build_type, cpio_data)
+    else:
+        prefer_pkgs_result = {}
+
+    return cpio_data.get(), prefer_pkgs_result
+
+
 def main(apiurl, store, opts, argv):
 
     repo = argv[0]
@@ -701,10 +787,10 @@ def main(apiurl, store, opts, argv):
         build_type = 'flatpak'
     if build_type not in ['spec', 'dsc', 'kiwi', 'arch', 'collax', 'livebuild',
                           'simpleimage', 'snapcraft', 'appimage', 'docker', 'helm',
-                          'podman', 'fissile', 'flatpak', 'preinstallimage']:
+                          'podman', 'fissile', 'flatpak', 'preinstallimage', 'productcompose']:
         raise oscerr.WrongArgs(
             'Unknown build type: \'%s\'. '
-            'Build description should end in .spec, .dsc, .kiwi, or .livebuild. '
+            'Build description should end in .spec, .dsc, .kiwi, .productcompose or .livebuild. '
             'Or being named PKGBUILD, build.collax, simpleimage, appimage.yml, '
             'Chart.yaml, snapcraft.yaml, flatpak.json, flatpak.yml, flatpak.yaml, '
             'preinstallimage or Dockerfile' % build_type)
@@ -730,7 +816,7 @@ def main(apiurl, store, opts, argv):
         buildargs.append('--threads=%s' % opts.threads)
     if opts.jobs:
         buildargs.append('--jobs=%s' % opts.jobs)
-    elif config['build-jobs'] > 1:
+    elif config['build-jobs'] > 0:
         buildargs.append('--jobs=%s' % config['build-jobs'])
     if opts.icecream or config['icecream'] != '0':
         if opts.icecream:
@@ -889,59 +975,16 @@ def main(apiurl, store, opts, argv):
     if xp:
         extra_pkgs += xp
 
-    prefer_pkgs = {}
-    build_descr_data = open(build_descr, 'rb').read()
-
-    # XXX: dirty hack but there's no api to provide custom defines
-    if opts.without:
-        s = ''
-        for i in opts.without:
-            s += "%%define _without_%s 1\n" % i
-        build_descr_data = s.encode() + build_descr_data
-    if opts._with:
-        s = ''
-        for i in opts._with:
-            s += "%%define _with_%s 1\n" % i
-        build_descr_data = s.encode() + build_descr_data
-    if opts.define:
-        s = ''
-        for i in opts.define:
-            s += "%%define %s\n" % i
-        build_descr_data = s.encode() + build_descr_data
-
-    cpiodata = None
-    servicefile = os.path.join(os.path.dirname(build_descr), "_service")
-    if not os.path.isfile(servicefile):
-        servicefile = os.path.join(os.path.dirname(build_descr), "_service")
-        if not os.path.isfile(servicefile):
-            servicefile = None
-        else:
-            print('Using local _service file')
-    buildenvfile = os.path.join(os.path.dirname(build_descr), "_buildenv." + repo + "." + arch)
-    if not os.path.isfile(buildenvfile):
-        buildenvfile = os.path.join(os.path.dirname(build_descr), "_buildenv")
-        if not os.path.isfile(buildenvfile):
-            buildenvfile = None
-        else:
-            print('Using local buildenv file: %s' % os.path.basename(buildenvfile))
-    if buildenvfile or servicefile:
-        if not cpiodata:
-            cpiodata = cpio.CpioWrite()
-
-    if opts.prefer_pkgs:
-        print('Scanning the following dirs for local packages: %s' % ', '.join(opts.prefer_pkgs))
-        if not cpiodata:
-            cpiodata = cpio.CpioWrite()
-        prefer_pkgs = get_prefer_pkgs(opts.prefer_pkgs, arch, build_type, cpiodata)
-
-    if cpiodata:
-        cpiodata.add(os.path.basename(build_descr.encode()), build_descr_data)
-        # buildenv must come last for compatibility reasons...
-        if buildenvfile:
-            cpiodata.add(b"buildenv", open(buildenvfile, 'rb').read())
-        if servicefile:
-            cpiodata.add(b"_service", open(servicefile, 'rb').read())
-        build_descr_data = cpiodata.get()
+    build_descr_data, prefer_pkgs = create_build_descr_data(
+        build_descr,
+        build_type=build_type,
+        repo=repo,
+        arch=arch,
+        prefer_pkgs=opts.prefer_pkgs,
+        define=opts.define,
+        define_with=opts._with,
+        define_without=opts.without,
+    )
 
     # special handling for overlay and rsync-src/dest
     specialcmdopts = []
@@ -1012,13 +1055,13 @@ def main(apiurl, store, opts, argv):
     except HTTPError as e:
         if e.code == 404:
             # check what caused the 404
-            if meta_exists(metatype='prj', path_args=(quote_plus(prj), ),
+            if meta_exists(metatype='prj', path_args=(prj, ),
                            template_args=None, create_new=False, apiurl=apiurl):
                 pkg_meta_e = None
                 try:
                     # take care, not to run into double trouble.
-                    pkg_meta_e = meta_exists(metatype='pkg', path_args=(quote_plus(prj),
-                                                                        quote_plus(pac)), template_args=None, create_new=False,
+                    pkg_meta_e = meta_exists(metatype='pkg', path_args=(prj, pac),
+                                             template_args=None, create_new=False,
                                              apiurl=apiurl)
                 except:
                     pass
@@ -1127,8 +1170,8 @@ def main(apiurl, store, opts, argv):
     imagefile = ''
     imagesource = ''
     imagebins = []
-    if build_as_user():
-        # preinstallimage extraction will fail
+    if build_as_user(vm_type):
+        # preinstallimage extraction will fail because unprivileged user cannot chroot or extract devices from the tarball
         bi.preinstallimage = None
     if build_type == 'preinstallimage':
         # preinstallimage would repackage just the previously built preinstallimage
@@ -1222,7 +1265,7 @@ def main(apiurl, store, opts, argv):
             buildargs.append('--oldpackages=%s' % old_pkg_dir)
 
     # Make packages from buildinfo available as repos for kiwi/docker/fissile
-    if build_type in ('kiwi', 'docker', 'podman', 'fissile'):
+    if build_type in ('kiwi', 'docker', 'podman', 'fissile', 'productcompose'):
         if os.path.exists('repos'):
             shutil.rmtree('repos')
         if os.path.exists('containers'):
@@ -1244,6 +1287,9 @@ def main(apiurl, store, opts, argv):
             # source fullfilename
             sffn = i.fullfilename
             filename = sffn.split("/")[-1]
+            if i.name == 'updateinfo.xml':
+                adir = 'updateinfo'
+                filename = i.package + ':' + i.repoarch + ':updateinfo.xml'
             # project/repo
             if i.name.startswith("container:"):
                 prdir = "containers/" + pdir + "/" + rdir
@@ -1402,7 +1448,7 @@ def main(apiurl, store, opts, argv):
 
     print('Writing build configuration')
 
-    if build_type in ('kiwi', 'docker', 'podman', 'fissile'):
+    if build_type in ('kiwi', 'docker', 'podman', 'fissile', 'productcompose'):
         rpmlist = ['%s %s\n' % (i.name, i.fullfilename) for i in bi.deps if not i.noinstall]
     else:
         rpmlist = []
