@@ -14,40 +14,37 @@
 # Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
 
 
-
 import os
 import re
-import sys
 import stat
+import sys
+from io import BytesIO
+from typing import Union
 
-#XXX: python 2.7 contains io.StringIO, which needs unicode instead of str
-#therefor try to import old stuff before new one here
-try:
-    from io import StringIO
-except ImportError:
-    from io import StringIO
-
-# workaround for python24
-if not hasattr(os, 'SEEK_SET'):
-    os.SEEK_SET = 0
 
 class ArError(Exception):
     """Base class for all ar related errors"""
-    def __init__(self, fn, msg):
-        Exception.__init__(self)
+
+    def __init__(self, fn: bytes, msg: str):
+        super().__init__()
         self.file = fn
         self.msg = msg
 
     def __str__(self):
-        return 'ar error: %s' % self.msg
+        return f"{self.msg}: {self.file.decode('utf-8')}"
+
 
 class ArHdr:
     """Represents an ar header entry"""
-    def __init__(self, fn, date, uid, gid, mode, size, fmag, off):
+
+    def __init__(self, fn: bytes, date: bytes, uid: bytes, gid: bytes, mode: bytes, size: bytes, fmag: bytes, off: bytes):
         self.file = fn.strip()
         self.date = date.strip()
         self.uid = uid.strip()
         self.gid = gid.strip()
+        if not mode.strip():
+            # provide a dummy mode for the ext_fn hdr
+            mode = b"0"
         self.mode = stat.S_IMODE(int(mode, 8))
         self.size = int(size)
         self.fmag = fmag
@@ -57,52 +54,64 @@ class ArHdr:
     def __str__(self):
         return '%16s %d' % (self.file, self.size)
 
-class ArFile(StringIO):
+
+class ArFile(BytesIO):
     """Represents a file which resides in the archive"""
+
     def __init__(self, fn, uid, gid, mode, buf):
-        StringIO.__init__(self, buf)
+        super().__init__(buf)
         self.name = fn
         self.uid = uid
         self.gid = gid
         self.mode = mode
 
-    def saveTo(self, dir = None):
+    def saveTo(self, dir=None):
         """
         writes file to dir/filename if dir isn't specified the current
         working dir is used. Additionally it tries to set the owner/group
         and permissions.
         """
+        if self.name.startswith(b"/"):
+            raise ArError(self.name, "Extracting files with absolute paths is not supported for security reasons")
+
         if not dir:
-            dir = os.getcwd()
-        fn = os.path.join(dir, self.name)
-        f = open(fn, 'wb')
-        f.write(self.getvalue())
-        f.close()
+            dir = os.getcwdb()
+        fn = os.path.join(dir, self.name.decode("utf-8"))
+
+        dir_path, _ = os.path.split(fn)
+        if dir_path:
+            os.makedirs(dir_path, exist_ok=True)
+
+        with open(fn, 'wb') as f:
+            f.write(self.getvalue())
         os.chmod(fn, self.mode)
         uid = self.uid
         if uid != os.geteuid() or os.geteuid() != 0:
             uid = -1
         gid = self.gid
-        if not gid in os.getgroups() or os.getegid() != 0:
+        if gid not in os.getgroups() or os.getegid() != 0:
             gid = -1
         os.chown(fn, uid, gid)
+        return fn
 
     def __str__(self):
         return '%s %s %s %s' % (self.name, self.uid,
                                 self.gid, self.mode)
 
+
 class Ar:
     """
     Represents an ar archive (only GNU format is supported).
     Readonly access.
     """
     hdr_len = 60
-    hdr_pat = re.compile('^(.{16})(.{12})(.{6})(.{6})(.{8})(.{10})(.{2})', re.DOTALL)
+    hdr_pat = re.compile(b'^(.{16})(.{12})(.{6})(.{6})(.{8})(.{10})(.{2})',
+                         re.DOTALL)
 
-    def __init__(self, fn = None, fh = None):
-        if fn == None and fh == None:
-            raise ArError(fn,'either \'fn\' or \'fh\' must be != None')
-        if fh != None:
+    def __init__(self, fn=None, fh=None):
+        if fn is None and fh is None:
+            raise ValueError('either \'fn\' or \'fh\' must be is not None')
+        if fh is not None:
             self.__file = fh
             self.__closefile = False
             self.filename = fh.name
@@ -123,7 +132,7 @@ class Ar:
 
     def _appendHdr(self, hdr):
         # GNU uses an internal '//' file to store very long filenames
-        if hdr.file.startswith('//'):
+        if hdr.file.startswith(b'//'):
             self.ext_fnhdr = hdr
         else:
             self.hdrs.append(hdr)
@@ -136,25 +145,29 @@ class Ar:
         data section. The end of such a filename is indicated with a trailing '/'.
         Another special file is the '/' which contains the symbol lookup table.
         """
+
+        # read extended header with long file names and then only seek into the right offsets
+        self.__file.seek(self.ext_fnhdr.dataoff, os.SEEK_SET)
+        ext_fnhdr_data = self.__file.read(self.ext_fnhdr.size)
+
         for h in self.hdrs:
-            if h.file == '/':
+            if h.file == b'/':
                 continue
-            # remove slashes which are appended by ar
-            h.file = h.file.rstrip('/')
-            if not h.file.startswith('/'):
+
+            if h.file.endswith(b"/"):
+                # regular file name
+                h.file = h.file[:-1]
                 continue
-            # handle long filename
-            off = int(h.file[1:len(h.file)])
-            start = self.ext_fnhdr.dataoff + off
-            self.__file.seek(start, os.SEEK_SET)
-            # XXX: is it safe to read all the data in one chunk? I assume the '//' data section
-            #      won't be too large
-            data = self.__file.read(self.ext_fnhdr.size)
-            end = data.find('/')
-            if end != -1:
-                h.file = data[0:end]
-            else:
-                raise ArError('//', 'invalid data section - trailing slash (off: %d)' % start)
+
+            # long file name
+            assert h.file[0:1] == b"/"
+            start = int(h.file[1:])
+            end = ext_fnhdr_data.find(b'/', start)
+
+            if end == -1:
+                raise ArError(b'//', 'invalid data section - trailing slash (off: %d)' % start)
+
+            h.file = ext_fnhdr_data[start:end]
 
     def _get_file(self, hdr):
         self.__file.seek(hdr.dataoff, os.SEEK_SET)
@@ -162,28 +175,17 @@ class Ar:
                       self.__file.read(hdr.size))
 
     def read(self):
-        """reads in the archive. It tries to use mmap due to performance reasons (in case of large files)"""
+        """reads in the archive."""
         if not self.__file:
-            import mmap
             self.__file = open(self.filename, 'rb')
-            try:
-                if sys.platform[:3] != 'win':
-                    self.__file = mmap.mmap(self.__file.fileno(), os.path.getsize(self.__file.name), prot=mmap.PROT_READ)
-                else:
-                    self.__file = mmap.mmap(self.__file.fileno(), os.path.getsize(self.__file.name))
-            except EnvironmentError as e:
-                if e.errno == 19 or ( hasattr(e, 'winerror') and e.winerror == 5 ):
-                    print('cannot use mmap to read the file, falling back to the default io', file=sys.stderr)
-                else:
-                    raise e
         else:
             self.__file.seek(0, os.SEEK_SET)
         self._init_datastructs()
         data = self.__file.read(7)
-        if data != '!<arch>':
+        if data != b'!<arch>':
             raise ArError(self.filename, 'no ar archive')
         pos = 8
-        while (len(data) != 0):
+        while len(data) != 0:
             self.__file.seek(pos, os.SEEK_SET)
             data = self.__file.read(self.hdr_len)
             if not data:
@@ -200,7 +202,10 @@ class Ar:
             pos += hdr.size + (hdr.size & 1)
         self._fixupFilenames()
 
-    def get_file(self, fn):
+    def get_file(self, fn: Union[str, bytes]):
+        # accept str for better user experience
+        if isinstance(fn, str):
+            fn = fn.encode("utf-8")
         for h in self.hdrs:
             if h.file == fn:
                 return self._get_file(h)
@@ -208,7 +213,19 @@ class Ar:
 
     def __iter__(self):
         for h in self.hdrs:
-            if h.file == '/':
+            if h.file == b'/':
                 continue
             yield self._get_file(h)
-        raise StopIteration()
+
+
+if __name__ == '__main__':
+    if len(sys.argv) != 2:
+        print('usage: %s <arfile>' % sys.argv[0])
+        sys.exit(1)
+    # a potential user might want to pass a bytes instead of a str
+    # to make sure that the ArError's file attribute is always a
+    # bytes
+    ar = Ar(fn=sys.argv[1])
+    ar.read()
+    for hdr in ar.hdrs:
+        print(hdr)
