@@ -9,7 +9,7 @@ def get_git_archive_version():
     """
     # the `version` variable contents get substituted during `git archive`
     # it requires adding this to .gitattributes: <path to this file> export-subst
-    version = "0.182.1"
+    version = "1.8.3"
     if version.startswith(("$", "%")):
         # "$": version hasn't been substituted during `git archive`
         # "%": "Format:" and "$" characters get removed from the version string (a GitHub bug?)
@@ -79,6 +79,6 @@ def get_version(version):
 
     result = git_tag
     if git_hash:
-        result += "+{}.git.{}".format(git_commits, git_hash)
+        result += f"+{git_commits}.git.{git_hash}"
 
     return result
