@@ -1,19 +1,25 @@
-import osc.core
-import osc.oscerr
 import os
 import sys
-import urllib.request, urllib.error, urllib.parse
-from common import GET, PUT, POST, DELETE, OscTestCase
-from xml.etree import cElementTree as ET
-#FIXTURES_DIR = os.path.join(os.getcwd(), 'commit_fixtures')
-FIXTURES_DIR = os.path.join(os.path.dirname(os.path.abspath(__file__)), 'commit_fixtures')
+import unittest
+from urllib.error import HTTPError
+from xml.etree import ElementTree as ET
+
+import osc.core
+import osc.oscerr
+
+from .common import GET, PUT, POST, DELETE, OscTestCase
+
+
+FIXTURES_DIR = os.path.join(os.path.dirname(__file__), 'commit_fixtures')
+
 
 def suite():
-    import unittest
-    return unittest.makeSuite(TestCommit)
+    return unittest.defaultTestLoader.loadTestsFromTestCase(TestCommit)
+
 
 rev_dummy = '<revision rev="repository">\n  <srcmd5>empty</srcmd5>\n</revision>'
 
+
 class TestCommit(OscTestCase):
     def _get_fixtures_dir(self):
         return FIXTURES_DIR
@@ -21,12 +27,13 @@ class TestCommit(OscTestCase):
     @GET('http://localhost/source/osctest/simple?rev=latest', file='testSimple_filesremote')
     @POST('http://localhost/source/osctest/simple?cmd=getprojectservices',
           exp='', text='<services />')
-    @POST('http://localhost/source/osctest/simple?comment=&cmd=commitfilelist&user=Admin',
+    @POST('http://localhost/source/osctest/simple?comment=&cmd=commitfilelist&user=Admin&withvalidate=1',
           file='testSimple_missingfilelist', expfile='testSimple_lfilelist')
     @PUT('http://localhost/source/osctest/simple/nochange?rev=repository',
-          exp='This file didn\'t change but\nis modified.\n', text=rev_dummy)
+         exp='This file didn\'t change but\nis modified.\n', text=rev_dummy)
     @POST('http://localhost/source/osctest/simple?comment=&cmd=commitfilelist&user=Admin',
           file='testSimple_cfilesremote', expfile='testSimple_lfilelist')
+    @GET('http://localhost/request?view=collection&project=osctest&package=simple&states=new%2Creview', file='testOpenRequests')
     def test_simple(self):
         """a simple commit (only one modified file)"""
         self._change_to_pkg('simple')
@@ -36,7 +43,7 @@ class TestCommit(OscTestCase):
         self.assertEqual(sys.stdout.getvalue(), exp)
         self._check_digests('testSimple_cfilesremote')
         self.assertTrue(os.path.exists('nochange'))
-        self.assertEqual(open('nochange', 'r').read(), open(os.path.join('.osc', 'nochange'), 'r').read())
+        self.assertFilesEqual('nochange', os.path.join('.osc', 'nochange'))
         self._check_status(p, 'nochange', ' ')
         self._check_status(p, 'foo', ' ')
         self._check_status(p, 'merge', ' ')
@@ -44,12 +51,13 @@ class TestCommit(OscTestCase):
     @GET('http://localhost/source/osctest/add?rev=latest', file='testAddfile_filesremote')
     @POST('http://localhost/source/osctest/add?cmd=getprojectservices',
           exp='', text='<services />')
-    @POST('http://localhost/source/osctest/add?comment=&cmd=commitfilelist&user=Admin',
+    @POST('http://localhost/source/osctest/add?comment=&cmd=commitfilelist&user=Admin&withvalidate=1',
           file='testAddfile_missingfilelist', expfile='testAddfile_lfilelist')
     @PUT('http://localhost/source/osctest/add/add?rev=repository',
          exp='added file\n', text=rev_dummy)
     @POST('http://localhost/source/osctest/add?comment=&cmd=commitfilelist&user=Admin',
           file='testAddfile_cfilesremote', expfile='testAddfile_lfilelist')
+    @GET('http://localhost/request?view=collection&project=osctest&package=add&states=new%2Creview', file='testOpenRequests')
     def test_addfile(self):
         """commit a new file"""
         self._change_to_pkg('add')
@@ -59,7 +67,7 @@ class TestCommit(OscTestCase):
         self.assertEqual(sys.stdout.getvalue(), exp)
         self._check_digests('testAddfile_cfilesremote')
         self.assertTrue(os.path.exists('add'))
-        self.assertEqual(open('add', 'r').read(), open(os.path.join('.osc', 'add'), 'r').read())
+        self.assertFilesEqual('add', os.path.join('.osc', 'add'))
         self.assertFalse(os.path.exists(os.path.join('.osc', '_to_be_added')))
         self._check_status(p, 'add', ' ')
         self._check_status(p, 'foo', ' ')
@@ -69,8 +77,9 @@ class TestCommit(OscTestCase):
     @GET('http://localhost/source/osctest/delete?rev=latest', file='testDeletefile_filesremote')
     @POST('http://localhost/source/osctest/delete?cmd=getprojectservices',
           exp='', text='<services />')
-    @POST('http://localhost/source/osctest/delete?comment=&cmd=commitfilelist&user=Admin',
+    @POST('http://localhost/source/osctest/delete?comment=&cmd=commitfilelist&user=Admin&withvalidate=1',
           file='testDeletefile_cfilesremote', expfile='testDeletefile_lfilelist')
+    @GET('http://localhost/request?view=collection&project=osctest&package=delete&states=new%2Creview', file='testOpenRequests')
     def test_deletefile(self):
         """delete a file"""
         self._change_to_pkg('delete')
@@ -116,13 +125,14 @@ class TestCommit(OscTestCase):
     @GET('http://localhost/source/osctest/multiple?rev=latest', file='testMultiple_filesremote')
     @POST('http://localhost/source/osctest/multiple?cmd=getprojectservices',
           exp='', text='<services />')
-    @POST('http://localhost/source/osctest/multiple?comment=&cmd=commitfilelist&user=Admin',
+    @POST('http://localhost/source/osctest/multiple?comment=&cmd=commitfilelist&user=Admin&withvalidate=1',
           file='testMultiple_missingfilelist', expfile='testMultiple_lfilelist')
     @PUT('http://localhost/source/osctest/multiple/nochange?rev=repository', exp='This file did change.\n', text=rev_dummy)
     @PUT('http://localhost/source/osctest/multiple/add?rev=repository', exp='added file\n', text=rev_dummy)
     @PUT('http://localhost/source/osctest/multiple/add2?rev=repository', exp='add2\n', text=rev_dummy)
     @POST('http://localhost/source/osctest/multiple?comment=&cmd=commitfilelist&user=Admin',
           file='testMultiple_cfilesremote', expfile='testMultiple_lfilelist')
+    @GET('http://localhost/request?view=collection&project=osctest&package=multiple&states=new%2Creview', file='testOpenRequests')
     def test_multiple(self):
         """a simple commit (only one modified file)"""
         self._change_to_pkg('multiple')
@@ -145,12 +155,13 @@ class TestCommit(OscTestCase):
     @GET('http://localhost/source/osctest/multiple?rev=latest', file='testPartial_filesremote')
     @POST('http://localhost/source/osctest/multiple?cmd=getprojectservices',
           exp='', text='<services />')
-    @POST('http://localhost/source/osctest/multiple?comment=&cmd=commitfilelist&user=Admin',
+    @POST('http://localhost/source/osctest/multiple?comment=&cmd=commitfilelist&user=Admin&withvalidate=1',
           file='testPartial_missingfilelist', expfile='testPartial_lfilelist')
     @PUT('http://localhost/source/osctest/multiple/add?rev=repository', exp='added file\n', text=rev_dummy)
     @PUT('http://localhost/source/osctest/multiple/nochange?rev=repository', exp='This file did change.\n', text=rev_dummy)
     @POST('http://localhost/source/osctest/multiple?comment=&cmd=commitfilelist&user=Admin',
           file='testPartial_cfilesremote', expfile='testPartial_lfilelist')
+    @GET('http://localhost/request?view=collection&project=osctest&package=multiple&states=new%2Creview', file='testOpenRequests')
     def test_partial(self):
         """commit only some files"""
         self._change_to_pkg('multiple')
@@ -172,10 +183,10 @@ class TestCommit(OscTestCase):
     @GET('http://localhost/source/osctest/simple?rev=latest', file='testSimple_filesremote')
     @POST('http://localhost/source/osctest/simple?cmd=getprojectservices',
           exp='', text='<services />')
-    @POST('http://localhost/source/osctest/simple?comment=&cmd=commitfilelist&user=Admin',
+    @POST('http://localhost/source/osctest/simple?comment=&cmd=commitfilelist&user=Admin&withvalidate=1',
           file='testSimple_missingfilelist', expfile='testSimple_lfilelist')
     @PUT('http://localhost/source/osctest/simple/nochange?rev=repository', exp='This file didn\'t change but\nis modified.\n',
-        exception=IOError('test exception'), text=rev_dummy)
+         exception=IOError('test exception'), text=rev_dummy)
     def test_interrupt(self):
         """interrupt a commit"""
         self._change_to_pkg('simple')
@@ -190,13 +201,14 @@ class TestCommit(OscTestCase):
     @GET('http://localhost/source/osctest/allstates?rev=latest', file='testPartial_filesremote')
     @POST('http://localhost/source/osctest/allstates?cmd=getprojectservices',
           exp='', text='<services />')
-    @POST('http://localhost/source/osctest/allstates?comment=&cmd=commitfilelist&user=Admin',
+    @POST('http://localhost/source/osctest/allstates?comment=&cmd=commitfilelist&user=Admin&withvalidate=1',
           file='testAllStates_missingfilelist', expfile='testAllStates_lfilelist')
     @PUT('http://localhost/source/osctest/allstates/add?rev=repository', exp='added file\n', text=rev_dummy)
     @PUT('http://localhost/source/osctest/allstates/missing?rev=repository', exp='replaced\n', text=rev_dummy)
     @PUT('http://localhost/source/osctest/allstates/nochange?rev=repository', exp='This file did change.\n', text=rev_dummy)
     @POST('http://localhost/source/osctest/allstates?comment=&cmd=commitfilelist&user=Admin',
           file='testAllStates_cfilesremote', expfile='testAllStates_lfilelist')
+    @GET('http://localhost/request?view=collection&project=osctest&package=allstates&states=new%2Creview', file='testOpenRequests')
     def test_allstates(self):
         """commit all files (all states are available except 'C')"""
         self._change_to_pkg('allstates')
@@ -220,8 +232,9 @@ class TestCommit(OscTestCase):
     @GET('http://localhost/source/osctest/add?rev=latest', file='testAddfile_filesremote')
     @POST('http://localhost/source/osctest/add?cmd=getprojectservices',
           exp='', text='<services />')
-    @POST('http://localhost/source/osctest/add?comment=&cmd=commitfilelist&user=Admin',
+    @POST('http://localhost/source/osctest/add?comment=&cmd=commitfilelist&user=Admin&withvalidate=1',
           file='testAddfile_cfilesremote', expfile='testAddfile_lfilelist')
+    @GET('http://localhost/request?view=collection&project=osctest&package=add&states=new%2Creview', file='testOpenRequests')
     def test_remoteexists(self):
         """file 'add' should be committed but already exists on the server"""
         self._change_to_pkg('add')
@@ -231,7 +244,7 @@ class TestCommit(OscTestCase):
         self.assertEqual(sys.stdout.getvalue(), exp)
         self._check_digests('testAddfile_cfilesremote')
         self.assertTrue(os.path.exists('add'))
-        self.assertEqual(open('add', 'r').read(), open(os.path.join('.osc', 'add'), 'r').read())
+        self.assertFilesEqual('add', os.path.join('.osc', 'add'))
         self.assertFalse(os.path.exists(os.path.join('.osc', '_to_be_added')))
         self._check_status(p, 'add', ' ')
         self._check_status(p, 'foo', ' ')
@@ -241,12 +254,13 @@ class TestCommit(OscTestCase):
     @GET('http://localhost/source/osctest/branch?rev=latest', file='testExpand_filesremote')
     @POST('http://localhost/source/osctest/branch?cmd=getprojectservices',
           exp='', text='<services />')
-    @POST('http://localhost/source/osctest/branch?comment=&cmd=commitfilelist&user=Admin&keeplink=1',
+    @POST('http://localhost/source/osctest/branch?comment=&cmd=commitfilelist&user=Admin&withvalidate=1&keeplink=1',
           file='testExpand_missingfilelist', expfile='testExpand_lfilelist')
     @PUT('http://localhost/source/osctest/branch/simple?rev=repository', exp='simple modified file.\n', text=rev_dummy)
     @POST('http://localhost/source/osctest/branch?comment=&cmd=commitfilelist&user=Admin&keeplink=1',
           file='testExpand_cfilesremote', expfile='testExpand_lfilelist')
     @GET('http://localhost/source/osctest/branch?rev=87ea02aede261b0267aabaa97c756e7a', file='testExpand_expandedfilesremote')
+    @GET('http://localhost/request?view=collection&project=osctest&package=branch&states=new%2Creview', file='testOpenRequests')
     def test_expand(self):
         """commit an expanded package"""
         self._change_to_pkg('branch')
@@ -273,11 +287,12 @@ class TestCommit(OscTestCase):
     @GET('http://localhost/source/osctest/added_missing?rev=latest', file='testAddedMissing_filesremote')
     @POST('http://localhost/source/osctest/added_missing?cmd=getprojectservices',
           exp='', text='<services />')
-    @POST('http://localhost/source/osctest/added_missing?comment=&cmd=commitfilelist&user=Admin',
+    @POST('http://localhost/source/osctest/added_missing?comment=&cmd=commitfilelist&user=Admin&withvalidate=1',
           file='testAddedMissing_missingfilelist', expfile='testAddedMissing_lfilelist')
     @PUT('http://localhost/source/osctest/added_missing/bar?rev=repository', exp='foobar\n', text=rev_dummy)
     @POST('http://localhost/source/osctest/added_missing?comment=&cmd=commitfilelist&user=Admin',
           file='testAddedMissing_cfilesremote', expfile='testAddedMissing_lfilelist')
+    @GET('http://localhost/request?view=collection&project=osctest&package=added_missing&states=new%2Creview', file='testOpenRequests')
     def test_added_missing2(self):
         """commit an added file, another added file missing (but it's not part of the commit)"""
         self._change_to_pkg('added_missing')
@@ -292,10 +307,10 @@ class TestCommit(OscTestCase):
     @GET('http://localhost/source/osctest/simple?rev=latest', file='testSimple_filesremote')
     @POST('http://localhost/source/osctest/simple?cmd=getprojectservices',
           exp='', text='<services />')
-    @POST('http://localhost/source/osctest/simple?comment=&cmd=commitfilelist&user=Admin',
+    @POST('http://localhost/source/osctest/simple?comment=&cmd=commitfilelist&user=Admin&withvalidate=1',
           file='testSimple_missingfilelist', expfile='testSimple_lfilelist')
     @PUT('http://localhost/source/osctest/simple/nochange?rev=repository',
-          exp='This file didn\'t change but\nis modified.\n', text=rev_dummy)
+         exp='This file didn\'t change but\nis modified.\n', text=rev_dummy)
     @POST('http://localhost/source/osctest/simple?comment=&cmd=commitfilelist&user=Admin',
           expfile='testSimple_lfilelist', text='an error occured', code=500)
     def test_commitfilelist_error(self):
@@ -303,11 +318,59 @@ class TestCommit(OscTestCase):
         self._change_to_pkg('simple')
         p = osc.core.Package('.')
         self._check_status(p, 'nochange', 'M')
-        self.assertRaises(urllib.error.HTTPError, p.commit)
+        self.assertRaises(HTTPError, p.commit)
         exp = 'Sending    nochange\nTransmitting file data .'
         self.assertEqual(sys.stdout.getvalue(), exp)
         self._check_status(p, 'nochange', 'M')
 
+    @GET('http://localhost/source/osctest/simple?rev=latest', file='testSimple_filesremote')
+    @POST('http://localhost/source/osctest/simple?cmd=getprojectservices',
+          exp='', text='<services />')
+    @POST('http://localhost/source/osctest/simple?comment=&cmd=commitfilelist&user=Admin&withvalidate=1',
+          file='testSimple_missingfilelistwithSHA', expfile='testSimple_lfilelist')
+    @POST('http://localhost/source/osctest/simple?comment=&cmd=commitfilelist&user=Admin',
+          file='testSimple_missingfilelistwithSHAsum', expfile='testSimple_lfilelistwithSHA')
+    @PUT('http://localhost/source/osctest/simple/nochange?rev=repository',
+         exp='This file didn\'t change but\nis modified.\n', text=rev_dummy)
+    @POST('http://localhost/source/osctest/simple?comment=&cmd=commitfilelist&user=Admin',
+          file='testSimple_cfilesremote', expfile='testSimple_lfilelistwithSHA')
+    @GET('http://localhost/request?view=collection&project=osctest&package=simple&states=new%2Creview', file='testOpenRequests')
+    def test_simple_sha256(self):
+        """a simple commit (only one modified file)"""
+        self._change_to_pkg('simple')
+        p = osc.core.Package('.')
+        p.commit()
+        exp = 'Sending    nochange\nTransmitting file data .\nCommitted revision 2.\n'
+        self.assertEqual(sys.stdout.getvalue(), exp)
+        self._check_digests('testSimple_cfilesremote')
+        self.assertTrue(os.path.exists('nochange'))
+        self.assertFilesEqual('nochange', os.path.join('.osc', 'nochange'))
+        self._check_status(p, 'nochange', ' ')
+        self._check_status(p, 'foo', ' ')
+        self._check_status(p, 'merge', ' ')
+
+    @GET('http://localhost/source/osctest/added_missing?rev=latest', file='testAddedMissing_filesremote')
+    @POST('http://localhost/source/osctest/added_missing?cmd=getprojectservices',
+          exp='', text='<services />')
+    @POST('http://localhost/source/osctest/added_missing?comment=&cmd=commitfilelist&user=Admin&withvalidate=1',
+          file='testAddedMissing_missingfilelistwithSHA', expfile='testAddedMissing_lfilelist')
+    @POST('http://localhost/source/osctest/added_missing?comment=&cmd=commitfilelist&user=Admin',
+          file='testAddedMissing_missingfilelistwithSHAsum', expfile='testAddedMissing_lfilelistwithSHA')
+    @PUT('http://localhost/source/osctest/added_missing/bar?rev=repository', exp='foobar\n', text=rev_dummy)
+    @POST('http://localhost/source/osctest/added_missing?comment=&cmd=commitfilelist&user=Admin',
+          file='testAddedMissing_cfilesremote', expfile='testAddedMissing_lfilelistwithSHA')
+    @GET('http://localhost/request?view=collection&project=osctest&package=added_missing&states=new%2Creview', file='testOpenRequests')
+    def test_added_missing2_sha256(self):
+        """commit an added file, another added file missing (but it's not part of the commit)"""
+        self._change_to_pkg('added_missing')
+        p = osc.core.Package('.')
+        p.todo = ['bar']
+        p.commit()
+        exp = 'Sending    bar\nTransmitting file data .\nCommitted revision 2.\n'
+        self.assertEqual(sys.stdout.getvalue(), exp)
+        self._check_status(p, 'add', '!')
+        self._check_status(p, 'bar', ' ')
+
+
 if __name__ == '__main__':
-    import unittest
     unittest.main()
