@@ -1,15 +1,21 @@
+import os
+import shutil
+import sys
+import unittest
+from xml.etree import ElementTree as ET
+
 import osc.core
 import osc.oscerr
-import os
-import sys
-from common import GET, PUT, POST, DELETE, OscTestCase
-from xml.etree import cElementTree as ET
-#FIXTURES_DIR = os.path.join(os.getcwd(), 'repairwc_fixtures')
-FIXTURES_DIR = os.path.join(os.path.dirname(os.path.abspath(__file__)), 'repairwc_fixtures')
+
+from .common import GET, PUT, POST, DELETE, OscTestCase
+
+
+FIXTURES_DIR = os.path.join(os.path.dirname(__file__), 'repairwc_fixtures')
+
 
 def suite():
-    import unittest
-    return unittest.makeSuite(TestRepairWC)
+    return unittest.defaultTestLoader.loadTestsFromTestCase(TestRepairWC)
+
 
 class TestRepairWC(OscTestCase):
     def _get_fixtures_dir(self):
@@ -19,7 +25,7 @@ class TestRepairWC(OscTestCase):
         try:
             meth(*args, **kwargs)
         except exception:
-            self.fail('%s raised' % exception.__name__)
+            self.fail(f'{exception.__name__} raised')
 
     def test_working_empty(self):
         """consistent, empty working copy"""
@@ -189,7 +195,7 @@ class TestRepairWC(OscTestCase):
         p = osc.core.Package('.', wc_check=False)
         p.wc_repair('http://localhost')
         self.assertTrue(os.path.exists(os.path.join('.osc', '_apiurl')))
-        self.assertEqual(open(os.path.join('.osc', '_apiurl')).read(), 'http://localhost\n')
+        self.assertFileContentEqual(os.path.join('.osc', '_apiurl'), 'http://localhost\n')
         self.assertEqual(p.apiurl, 'http://localhost')
 
     def test_invalidapiurl(self):
@@ -198,20 +204,9 @@ class TestRepairWC(OscTestCase):
         p = osc.core.Package('.', wc_check=False)
         p.wc_repair('http://localhost')
         self.assertTrue(os.path.exists(os.path.join('.osc', '_apiurl')))
-        self.assertEqual(open(os.path.join('.osc', '_apiurl')).read(), 'http://localhost\n')
+        self.assertFileContentEqual(os.path.join('.osc', '_apiurl'), 'http://localhost\n')
         self.assertEqual(p.apiurl, 'http://localhost')
 
-    def test_invalidapiurl_param(self):
-        """pass an invalid apiurl to wc_repair"""
-        try:
-            from urllib.error import URLError
-        except ImportError:
-            from urllib.error import URLError
-        self._change_to_pkg('invalid_apiurl')
-        p = osc.core.Package('.', wc_check=False)
-        self.assertRaises(URLError, p.wc_repair, 'http:/localhost')
-        self.assertRaises(URLError, p.wc_repair, 'invalid')
-
     def test_noapiurlNotExistingApiurl(self):
         """the package wc has no _apiurl file and no apiurl is passed to repairwc"""
         self._change_to_pkg('noapiurl')
@@ -222,7 +217,6 @@ class TestRepairWC(OscTestCase):
 
     def test_project_noapiurl(self):
         """the project wc has no _apiurl file"""
-        import shutil
         prj_dir = os.path.join(self.tmpdir, 'prj_noapiurl')
         shutil.copytree(os.path.join(self._get_fixtures_dir(), 'prj_noapiurl'), prj_dir)
         storedir = os.path.join(prj_dir, osc.core.store)
@@ -231,36 +225,8 @@ class TestRepairWC(OscTestCase):
         prj.wc_repair('http://localhost')
         self.assertTrue(os.path.exists(os.path.join(storedir, '_apiurl')))
         self.assertTrue(os.path.exists(os.path.join(storedir, '_apiurl')))
-        self.assertEqual(open(os.path.join(storedir, '_apiurl'), 'r').read(), 'http://localhost\n')
+        self.assertFileContentEqual(os.path.join(storedir, '_apiurl'), 'http://localhost\n')
 
-    def test_project_invalidapiurl(self):
-        """the project wc has an invalid _apiurl file (invalid url format)"""
-        import shutil
-        prj_dir = os.path.join(self.tmpdir, 'prj_invalidapiurl')
-        shutil.copytree(os.path.join(self._get_fixtures_dir(), 'prj_invalidapiurl'), prj_dir)
-        storedir = os.path.join(prj_dir, osc.core.store)
-        self.assertRaises(osc.oscerr.WorkingCopyInconsistent, osc.core.Project, prj_dir, getPackageList=False)
-        prj = osc.core.Project(prj_dir, wc_check=False, getPackageList=False)
-        prj.wc_repair('http://localhost')
-        self.assertTrue(os.path.exists(os.path.join(storedir, '_apiurl')))
-        self.assertTrue(os.path.exists(os.path.join(storedir, '_apiurl')))
-        self.assertEqual(open(os.path.join(storedir, '_apiurl'), 'r').read(), 'http://localhost\n')
-
-    def test_project_invalidapiurl_param(self):
-        """pass an invalid apiurl to wc_repair"""
-        import shutil
-        try:
-            from urllib.error import URLError
-        except ImportError:
-            from urllib.error import URLError
-        prj_dir = os.path.join(self.tmpdir, 'prj_invalidapiurl')
-        shutil.copytree(os.path.join(self._get_fixtures_dir(), 'prj_invalidapiurl'), prj_dir)
-        storedir = os.path.join(prj_dir, osc.core.store)
-        self.assertRaises(osc.oscerr.WorkingCopyInconsistent, osc.core.Project, prj_dir, getPackageList=False)
-        prj = osc.core.Project(prj_dir, wc_check=False, getPackageList=False)
-        self.assertRaises(URLError, prj.wc_repair, 'http:/localhost')
-        self.assertRaises(URLError, prj.wc_repair, 'invalid')
 
 if __name__ == '__main__':
-    import unittest
     unittest.main()
